"""
MAGICapp_get_sections

Get all sections (chapters) of a specific MAGICapp clinical guideline. Returns the structural org...
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def MAGICapp_get_sections(
    guideline_id: int,
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> Any:
    """
    Get all sections (chapters) of a specific MAGICapp clinical guideline. Returns the structural org...

    Parameters
    ----------
    guideline_id : int
        Numeric guideline ID (use the publishedId from MAGICapp_list_guidelines, e.g....
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    Any
    """
    # Handle mutable defaults to avoid B006 linting error

    return get_shared_client().run_one_function(
        {"name": "MAGICapp_get_sections", "arguments": {"guideline_id": guideline_id}},
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["MAGICapp_get_sections"]
